%-------------------------------------------------------------------------
% MATLAB code for Hennequin & Hommes (2022)
% "Managing bubbles in experimental asset markets with monetary policy”
%-------------------------------------------------------------------------
% SIMULATIONS WITH HOMOGENEOUS EXPECTATIONS (Figures A1-A2 in Online Appendix)
%-------------------------------------------------------------------------

% set rule (op'RB', 'ADA', 'WTR', 'STR', 'AA')  
  rule = 'RB';

% simulation horizon (default: T=50)
  T = 50;

% set monetary policy
  switch rule
      case 'RB'
           phis = [0; 0.001; 0.01; 0.1];
      otherwise
           phis = [0; 0.001; 0.1];
  end
  prices = NaN(T,length(phis));
  interest = NaN(T,length(phis));
  for p=1:length(phis)
      phi = phis(p);

    % create empty vectors and matrices
      time = transpose(1:T);
      predict = NaN(T+1,1);
      simprice = zeros(T,1);
      x = zeros(50,1);
      
    % interest rate and dividend
      r = 0.05*ones(T,1);
      ybar = 3;
      fundamental = ybar/r(1);
      
    % initialization: period 1 and 2
      % initial prices (default: [50; 55])
      simprice(1:2) = [50; 55];
      x(1:2) = [15; 15.75];
      % prediction NAI
      predict(3) = simprice(2);
    % simulation: period 3-T
      for t=3:T
          % prices for RB; predictions for other rules
          switch rule
              case 'RB'
                   x(t) = 1.05*x(t-1)+(phi/60)*x(t-1)*x(t-2)+phi*x(t-2);
                   simprice(t) = x(t) + fundamental;
              case 'ADA'
                   predict(t+1) = 0.65*simprice(t-1)+0.35*predict(t,1);
              case 'WTR'
                   predict(t+1) = simprice(t-1)+0.4*(simprice(t-1)-simprice(t-2));
              case 'STR'
                   predict(t+1) = simprice(t-1)+1.3*(simprice(t-1)-simprice(t-2));
              case 'AA'
                   predict(t+1) = 0.5*(fundamental+simprice(t-1))+(simprice(t-1)-simprice(t-2));   
           end
          % take account of lower bound 0 and upper bound 1000
            if     predict(t+1) < 0
                   predict(t+1) = 0;
            elseif predict(t+1) > 1000
                   predict(t+1) = 1000;
            end
          % monetary policy: Taylor-rule with ZLB
            dev = (simprice(t-1)-fundamental)/fundamental;
            r(t) = 0.05+phi*dev;
            if  r(t) < 0
                r(t) = 0;
            end
          % simulated prices
            switch rule
                   case {'ADA', 'WTR', 'STR', 'AA'}
                        simprice(t) = (1/(1+r(t)))*(predict(t+1)+ybar);
            end
      end
      
    % save policy results  
      prices(:,p) = simprice;
      interest(:,p) = r;
  
  end
  
% parameters for improved figures
  width = 3.5;   % Width in inches
  height = 1.5;  % Height in inches
  alw = 0.75;    % AxesLineWidth
  fsz = 11;      % Fontsize
  lw = 2;        % LineWidth
  msz = 3;       % MarkerSize 
  red = [0.8500 0.3250 0.0980];    % New red
  blue = [0 0.4470 0.7410];        % New blue
  green = [0.4660 0.6740 0.1880];  % New green
  purple = [0.4940 0.1840 0.5560]; % New purple
  
% plot prices of all policies
  figure
  pos = get(gcf, 'Position');
  set(gcf, 'Position', [pos(1) pos(2) width*150, height*200]);
  set(gca, 'FontSize', fsz, 'LineWidth', alw);
  plot(prices(:,1), '-o', 'Color', red, 'LineWidth', lw, 'MarkerSize', msz, 'MarkerFaceColor', 'r')
  hold on
  plot(prices(:,2), '-+', 'Color', blue, 'LineWidth', lw, 'Marker', '+', 'MarkerSize', msz)
  hold on
  plot(prices(:,3), '-v', 'Color', green, 'LineWidth', lw, 'Marker', 'v', 'MarkerSize', msz)
  hold on
  switch rule
      case 'RB'
           plot(prices(:,4), '-x', 'Color', purple, 'LineWidth', lw, 'Marker', 'x', 'MarkerSize', msz)
  end
  hold on
  plot([0 T],[fundamental fundamental], '--k',  'LineWidth', lw)
  hold off
  switch rule
      case 'RB'
           axis([0 T 0 1000])
           set(gca,'XTick',0:10:T,'YTick',0:250:1000)
           legend('phi = 0', 'phi = 0.001', 'phi = 0.01', 'phi = 0.1')
      case 'STR'     
           axis([0 T 0 500])
           set(gca,'XTick',0:10:T,'YTick',0:100:500)
           legend('phi = 0', 'phi = 0.001', 'phi = 0.1', 'Location', 'NorthWest')
      otherwise
           axis([0 T 50 70])
           set(gca,'XTick',0:10:T,'YTick',50:10:70)
           legend('phi = 0', 'phi = 0.001', 'phi = 0.1', 'Location', 'NorthWest')
  end
  ylabel('Price')

% plot interest rates of all policies
  figure
  pos = get(gcf, 'Position');
  set(gcf, 'Position', [pos(1) pos(2) width*150, height*150]);
  set(gca, 'FontSize', fsz, 'LineWidth', alw);
  plot(interest(:,2), '-v', 'Color', blue, 'LineWidth', lw, 'Marker', '+', 'MarkerSize', msz)
  hold on
  plot(interest(:,3), '-s', 'Color', green, 'LineWidth', lw, 'Marker', 'v', 'MarkerSize', msz)
  hold on
  switch rule
      case 'RB'
            plot(interest(:,4), '-x', 'Color', purple, 'LineWidth', lw, 'Marker', 'x', 'MarkerSize', msz)
            hold on
  end
  plot([0 T],[r(1) r(1)], '--k', 'LineWidth', lw)
  hold off
  switch rule
      case 'RB'
           axis([0 T 0 1])
           set(gca,'XTick',0:10:T,'YTick',0:0.25:1)
           legend('phi = 0.001', 'phi = 0.01', 'phi = 0.1')
      case 'STR'  
           axis([0 T 0 0.3])
           set(gca,'XTick',0:10:T,'YTick',0:0.1:0.3)
           legend('phi = 0.001','phi = 0.1')
      otherwise
           axis([0 T 0 0.1])
           set(gca,'XTick',0:10:T,'YTick',0:0.05:0.1)
           legend('phi = 0.001','phi = 0.1')
  end
  ylabel('Interest rate')
