%-------------------------------------------------------------------------
% MATLAB code for Hennequin & Hommes (2022)
% "Managing bubbles in experimental asset markets with monetary policy”
%-------------------------------------------------------------------------

% import group data from Excel
  marketprice = xlsread('policyLtFE_allmarkets.xlsx', 'Price');
  interest = xlsread('policyLtFE_allmarkets.xlsx', 'Interest');
  prediction = xlsread('policyLtFE_allmarkets.xlsx', 'Prediction');

% number of markets
  num_markets = size(marketprice, 2);  
  
% group data by treatment
  T1_price = marketprice(:,1:8);
  T1_interest = interest(:,1:8);
  T1_predict = prediction(:,1:48);
  T2_price = marketprice(:,9:16);
  T2_interest = interest(:,9:16);
  T2_predict = prediction(:,49:96);
  T3_price = marketprice(:,17:24);
  T3_interest = interest(:,17:24);
  T3_predict = prediction(:,97:144);
  T4_price = marketprice(:,25:32);
  T4_interest = interest(:,25:32);
  T4_predict = prediction(:,145:192);
  T5_price = marketprice(:,33:40);
  T5_interest = interest(:,33:40);  
  T5_predict = prediction(:,193:240);

%-------------------------------------------------------------------------
% SUMMARY STATISTICS (Table C1 in Online Appendix)
%-------------------------------------------------------------------------

% Statistics per market
  % Market prices: mean, std, min, max, RAD, RD
  stats_prices = NaN(num_markets,6);
  dev = (marketprice - 60)/60;
  absdev = abs(dev);
  for i=1:num_markets
      stats_prices(i,1) = mean(marketprice(:,i));
      stats_prices(i,2) = std(marketprice(:,i));
      stats_prices(i,3) = min(marketprice(:,i));
      stats_prices(i,4) = max(marketprice(:,i));
      stats_prices(i,5) = mean(absdev(:,i));
      stats_prices(i,6) = mean(dev(:,i));
  end
  % Interest rates: mean, std, min, max
  stats_interest = NaN(num_markets,4);
  for i=1:num_markets
      stats_interest(i,1) = mean(interest(:,i));
      stats_interest(i,2) = std(interest(:,i));
      stats_interest(i,3) = min(interest(:,i));
      stats_interest(i,4) = max(interest(:,i));
  end

% Averages per treatment
  % Market prices: averages of mean, std, min, max, RAD, RD
  mean_stats_prices = NaN(5,6);
  for i=1:6
      for k=0:4
          mean_stats_prices(k+1,i) = mean(stats_prices((1+k*8):(8+k*8),i));
      end
  end
  % Interest rates: averages of mean, std, min, max
  mean_stats_interest = NaN(5,4);
  for i=1:4
      for k=0:4
          mean_stats_interest(k+1,i) = mean(stats_interest((1+k*8):(8+k*8),i));
      end
  end

%-------------------------------------------------------------------------
% PLOTS PER MARKET (Figures C1-C5 in Online Appendix)
%-------------------------------------------------------------------------

% Parameters for improved figures
  width = 3.5;              % Width in inches
  height = 1.5;             % Height in inches
  alw = 0.75;               % AxesLineWidth
  fsz = 11;                 % Fontsize
  lw = 1.5;                 % LineWidth
  msz = 3;                  % MarkerSize

% Define y-axis for each plot
  ymax_price = [1000; 1000; 200;  1000; 1000; 1000; 200; 200;
                200;  200;  200;  200;  200;  200;  300; 200;
                200;  200;  200;  300;  300;  300;  500; 300;
                200;  300;  200;  200;  200;  200;  200; 200;
                1000; 1000; 1000; 200;  200;  300;  200; 200];
  ytick_price = [250; 250; 50;  250; 250; 250; 50;  50;
                 50;  50;  50;  50;  50;  50;  50;  50;
                 50;  50;  50;  50;  50;  50;  100; 50;
                 50;  50;  50;  50;  50;  50;  50;  50;
                 250; 250; 250; 50;  50;  50;  50;  50];
  ymax_interest = [7.5; 7.5; 7.5; 7.5; 7.5; 7.5; 7.5; 7.5;
                   25;  25;  25;  25;  25;  25;  40;  25;
                   25;  25;  25;  40;  40;  40;  80;  40;
                   25;  40;  25;  25;  25;  25;  25;  25;
                   80;  80;  80;  25;  25;  40;  25;  25];
  ytick_interest = [2.5; 2.5; 2.5; 2.5; 2.5; 2.5; 2.5; 2.5;
                    5;   5;   5;   5;   5;   5;   10;  5;
                    5;   5;   5;   10;  10;  10;  20;  10;
                    5;   10;  5;   5;   5;   5;   5;   5;
                    20;  20;  20;  5;   5;   10; 5;   5];

% Plots per market
  for i=1:40
      % Plot prices and individual predictions
      figure(i*2-1)
      pos = get(gcf, 'Position');
      set(gcf, 'Position', [pos(1) pos(2) width*100, height*100]);
      set(gca, 'FontSize', fsz, 'LineWidth', alw);
      plot(prediction(:,(i*6-5):(i*6)),'LineWidth',lw)
      hold on
      plot(marketprice(:,i),'k','LineWidth',3)
      hold on
      plot([0 51],[60 60], '--k','LineWidth',lw)
      hold off
      axis([0 51 0 ymax_price(i)])
      set(gca,'XTick',0:10:51,'YTick',0:ytick_price(i):ymax_price(i))
      ylabel('Price, prediction')
      % Plot interest rates
      figure(i*2)
      pos = get(gcf, 'Position');
      set(gcf, 'Position', [pos(1) pos(2) width*100, height*80]);
      set(gca, 'FontSize', fsz, 'LineWidth', alw);
      plot(interest(:,i),'-b','LineWidth',lw,'MarkerSize',msz)
      hold on
      plot([0 51],[5 5], '--k','LineWidth',lw)
      hold off
      axis([0 51 0 ymax_interest(i)])
      set(gca,'XTick',0:10:51,'YTick',0:ytick_interest(i):ymax_interest(i))
      ylabel('Interest rate (%)')
  end


